# pySIPFENN
This repository contains SIPFENN software to use Python all the way from atomic structure to the resulting energy, not relying on 3rd party non-Python tools 
for featurization or analysis. It is also designed to allow repid deployment by a researcher with minimal coding experience.
